package net.rzdata.domain;

import lombok.*;
import net.rzdata.exception.BaseException;

@Getter
@ToString
@NoArgsConstructor
@AllArgsConstructor(access = AccessLevel.PROTECTED)
public class Result<T> {

    public static final String SUCCESS_CODE = "00000";
    public static final String SUCCESS_MESSAGE = "操作成功";

    private String code;
    private String message;
    private T data;

    public static <T> Result<T> ok() {
        return new Result<>(SUCCESS_CODE, SUCCESS_MESSAGE, null);
    }

    public static <T> Result<T> ok(T data) {
        return new Result<>(SUCCESS_CODE, SUCCESS_MESSAGE, data);
    }

    public static <T> Result<T> fail(BaseException e) {
        return new Result<>(e.getCode(), e.getMessage(), null);
    }

    public static <T> Result<T> fail(BaseException e, T data) {
        return new Result<>(e.getCode(), e.getMessage(), data);
    }

    public static <T> Result<T> fail(BaseException e, String message) {
        return new Result<>(e.getCode(), message, null);
    }

    public static <T> Result<T> fail(BaseException e, String message, T data) {
        return new Result<>(e.getCode(), message, data);
    }
}
